#
# spec file for package python-pyee
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%if 0%{?sle_version} > 150200
%bcond_with test
%else
%bcond_without test
%endif

Name:           python-pyee
Version:        6.0.0
Release:        bp154.1.33
Summary:        A port of node.js's EventEmitter to python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/jfhbrook/pyee
Source:         https://files.pythonhosted.org/packages/source/p/pyee/pyee-%{version}.tar.gz
Source99:       https://raw.githubusercontent.com/jfhbrook/pyee/master/LICENSE
# PATCH-FIX-UPSTREAM fix-build-requirements.patch
Patch0:         fix-build-requirements.patch
BuildRequires:  %{python_module PyHamcrest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module vcversioner}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
%if %{with test}
BuildRequires:  %{python_module Twisted}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pytest-runner}
BuildRequires:  python3-pytest-asyncio
%endif
# /SECTION
%python_subpackages

%description
pyee supplies an ``EventEmitter`` object similar to the ``EventEmitter``
from Node.js.

%prep
%setup -q -n pyee-%{version}
%patch0 -p1
# https://github.com/jfhbrook/pyee/issues/58
cp %{SOURCE99} .

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test} && 0%{?suse_version} >= 1500
%check
# Only run tests for python3
%{python_expand #
if [ "${python_flavor}" == "python3" ]; then
    python3 setup.py test
fi
}
%endif

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Sat Feb 20 2021 Yuchen Lin <mlin+factory@suse.de>
- Disable test in Leap
* Thu Apr 25 2019 pgajdos@suse.com
- version update to 6.0.0
  * Added a ``BaseEventEmitter`` class which is entirely synchronous and
    intended for simple use and for subclassing
  * Added an ``AsyncIOEventEmitter`` class for intended use with asyncio
  * Added a ``TwistedEventEmitter`` class for intended use with twisted
  * Added an ``ExecutorEventEmitter`` class which runs events in an executor
  * Deprecated ``EventEmitter`` (use one of the new classes)
- modified patches
  %% fix-build-requirements.patch (refreshed)
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Oct 29 2018 Todd R <toddrme2178@gmail.com>
- python-hamcrest was renamed to python-PyHamcrest
* Thu Jul 19 2018 mcepl@suse.com
- Clean up SPEC
- Add missing BuildRequires
* Sun Mar  4 2018 alarrosa@suse.com
- Fix LICENSE url
* Tue Feb 20 2018 alarrosa@suse.com
- pytest-asyncio was build requirement by pyee's setup.py file, but
  it was only used for tests. On top of that, the python-pytest-asyncio
  package is only available for python3, so now we only do tests on
  python3 and a patch was added to fix the requirements:
  * fix-build-requirements.patch
- Since the tests require at least python 3.5, only run the tests when
  suse_version >= 1500
* Fri Jan  5 2018 alarrosa@suse.com
- Update to version 5.0.0
  * CHANGELOG.md reformatted to CHANGELOG.rst
  * Added CONTRIBUTORS.rst
  * The listeners method no longer returns the raw list of listeners, and
    instead returns a list of unwrapped listeners; This means that mutating
    listeners on the EventEmitter by mutating the list returned by this method
    isn't possible anymore, and that for once handlers this method returns the
    unwrapped handler rather than the wrapped handler
  * once API now returns the unwrapped handler in both decorator and
    non-decorator cases
  * Possible to remove once handlers with unwrapped handlers
  * Internally, listeners are now stored on a OrderedDict rather than a list
  * Minor stylistic tweaks to make code more pythonic
- Update to version 4.0.1
  * Fix bug in setup.py; Now publishable
- Update to version 4.0.0
  * Coroutines now work with .once Wrapped listener is removed prior to hook
  * execution rather than after for synchronous .once handlers
- Add LICENSE file from upstream
* Tue Sep  5 2017 alarrosa@suse.com
- Initial release of python-pyee 3.0.3
